# This file is part of Remote Support Desktop
# https://gitlab.das-netzwerkteam.de/RemoteWebApp/rwa.support.sessionservice
# Copyright 2020, 2021 Jonathan Weth <dev@jonathanweth.de>
# Copyright 2020 Daniel Teichmann <daniel.teichmann@das-netzwerkteam.de>
# Copyright 2020 Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
# SPDX-License-Identifier: GPL-2.0-or-later
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the
# Free Software Foundation, Inc.,
# 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <https://www.gnu.org/licenses/>.

import os
import tempfile

TEMP_DIR_PATH = os.path.join(tempfile.gettempdir(), "rwa.support.sessionservice")
lock_file_path = os.path.join(TEMP_DIR_PATH, "rwa.support.sessionservice.lock")


def lock():
    """Create lock file."""
    os.makedirs(TEMP_DIR_PATH, exist_ok=True)
    with open(lock_file_path, "w") as f:
        f.write("lock")


def is_locked():
    """Check if the lock file exists."""
    return os.path.exists(lock_file_path)


def unlock():
    """Remove the lock file."""
    try:
        os.remove(lock_file_path)
    except FileNotFoundError:
        pass


# Always ensure temp dir
os.makedirs(TEMP_DIR_PATH, exist_ok=True)
